@@ -1,4 +1,4 @@
-import uml
+from . import uml
 
 if __name__ == "__main__":
     uml.classdiagram()
